﻿using C1.Win.C1FlexGrid;
using System;
using System.Configuration;
using System.Data;
using System.Data.OleDb;
using System.Drawing;
using System.Windows.Forms;

namespace FlexGridColumnFooters
{
   public partial class Form1 : Form
    {
        private DataTable _collectionTable = new DataTable();
        public Form1()
        {
            InitializeComponent();
        }

        #region Form_Load
        private void Form1_Load(object sender, EventArgs e)
        {
            _flex.Cols.Fixed = 0;
            _flex.DataSource = GetDataTable();
            DataColumn dc = new DataColumn("Poster", typeof(Image));
            _collectionTable.Columns.Add(dc);
            _flex.Cols["Poster"].Move(0);

            //Call FlexGridStyling() method for Styling FlexGrid      
            FlexGridStyling();
            //Call SetImages() Method to set Images in "Poster" Column
            SetImages();
            //Call Footer() Method for Footer Editing
            Footer();
            //Call Grouping() Method For Applying Grouping on FlexGrid
            Grouping();
            //Owner Draw 
            _flex.DrawMode = DrawModeEnum.OwnerDraw;
            _flex.OwnerDrawCell += _flex_OwnerDrawCell;
        }
        #endregion

        #region Grouping Method
        private void Grouping()
        {
            _flex.Tree.Column = 1;
            _flex.GroupDescriptions = new GroupDescription[] { new GroupDescription("Studio") };
            //Resize node row
            for (int i = 1; i < _flex.Rows.Count - 1; i++)
            {
                if (_flex.Rows[i].IsNode)
                {
                    _flex.Rows[i].Style.Font = new Font("Times New Roman", 11, FontStyle.Bold);             
                    _flex.Rows[i].Height = 40;
                }
                //Hide Grouped Column
                _flex.Cols["Studio"].Visible = false;
            }
        }
        #endregion

        #region OwnerDrawCell Event Handler   
        private void _flex_OwnerDrawCell(object sender, OwnerDrawCellEventArgs e)
        {
            if (e.Col == _flex.Cols["Release Date"].Index && e.Row == _flex.Rows.Count - 1)
            {
                DateTime MyDateTime = DateTime.Parse(e.Text);
                e.Text = "Latest Release : " + MyDateTime.ToString("dd MMM yyyy");
            }
        }

        #endregion

        #region Footer Method
        private void Footer()
        {
            //Position 
            _flex.Footers.Fixed = true;
            //Styling         
            _flex.Styles.Footer.Font = new Font("Times New Roman", 12, FontStyle.Bold);
            _flex.Styles.Footer.WordWrap = true;
            //Adding Footer Row
            _flex.Footers.Descriptions.Add(new FooterDescription());
            //Height of Footers        
            for (int i = _flex.Rows.Count - 1; i >= _flex.Rows.Count - _flex.Footers.Descriptions.Count; i--)
            {
                _flex.Rows[i].Height = 50;
            }
            //Adding Aggregates and Expressions
            _flex.Footers.Descriptions[0].Aggregates.Add(new AggregateDefinition() { Column = 3, Caption = "Max Budget (In Million $): ", Aggregate = AggregateEnum.Max });
            _flex.Footers.Descriptions[0].Aggregates.Add(new AggregateDefinition() { Column = 5, Caption = "Max Theaters Covered : ", Aggregate = AggregateEnum.Max });
            _flex.Footers.Descriptions[0].Aggregates.Add(new AggregateDefinition() { Column = 6, Caption = "Average (In Million $): ", Aggregate = AggregateEnum.Average });
            _flex.Footers.Descriptions[0].Aggregates.Add(new AggregateDefinition() { Column = 7, Caption = "Total Gross (In Million $): ", Aggregate = AggregateEnum.None });
            _flex.Footers.Descriptions[0].Aggregates.Add(new AggregateDefinition() {PropertyName = "Release Date", Aggregate = AggregateEnum.Max });
            _flex.Footers.Descriptions[0].Aggregates[3].Expression = "Sum([WorldWide Collection]-[Budget])";
        }

        #endregion

        #region Set Images Method
        private void SetImages()
        {
            _flex.Cols[1].Style.ImageAlign = ImageAlignEnum.CenterCenter;
            _collectionTable.Rows[0]["Poster"] = Properties.Resources.antman;
            _collectionTable.Rows[1]["Poster"] = Properties.Resources.antmanandWasp;
            _collectionTable.Rows[2]["Poster"] = Properties.Resources.avengerAgeofUltron;
            _collectionTable.Rows[3]["Poster"] = Properties.Resources.AvengersEndGame;
            _collectionTable.Rows[4]["Poster"] = Properties.Resources.Avengersinfinity;
            _collectionTable.Rows[5]["Poster"] = Properties.Resources.blackpanther;
            _collectionTable.Rows[6]["Poster"] = Properties.Resources.captainamericaCivilWar;
            _collectionTable.Rows[7]["Poster"] = Properties.Resources.CaptainAmericaTheFirst;
            _collectionTable.Rows[8]["Poster"] = Properties.Resources.captainamericaThewinterSolider;
            _collectionTable.Rows[9]["Poster"] = Properties.Resources.Captainmarvel;
            _collectionTable.Rows[10]["Poster"] = Properties.Resources.DocStrange;
            _collectionTable.Rows[11]["Poster"] = Properties.Resources.GOGVol1;
            _collectionTable.Rows[12]["Poster"] = Properties.Resources.GOGVol2;
            _collectionTable.Rows[13]["Poster"] = Properties.Resources.Hulk;
            _collectionTable.Rows[14]["Poster"] = Properties.Resources.ironman1;
            _collectionTable.Rows[15]["Poster"] = Properties.Resources.ironman2;
            _collectionTable.Rows[16]["Poster"] = Properties.Resources.ironman3;
            _collectionTable.Rows[17]["Poster"] = Properties.Resources.marvelstheAvengers;
            _collectionTable.Rows[18]["Poster"] = Properties.Resources.spidermanhomeComing;
            _collectionTable.Rows[19]["Poster"] = Properties.Resources.thor2011;
            _collectionTable.Rows[20]["Poster"] = Properties.Resources.thorRagnorok;
            _collectionTable.Rows[21]["Poster"] = Properties.Resources.thortheDarkWorld;

        }
        #endregion

        #region FlexGridStyling Method
        private void FlexGridStyling()
        {
            //Sizing
            _flex.Rows.DefaultSize = 100;
            for (int i = 1; i <= _flex.Cols.Count - 1; i++)
            {
                _flex.Cols[i].StarWidth = "*";
            }
            _flex.Cols["Poster"].Width = 265;
            _flex.Cols["Film"].Width = 200;
            //Fixed Cells Styles
            _flex.Styles.Fixed.Font = new Font("Times New Roman", 13, FontStyle.Bold);
            _flex.Styles.Fixed.TextAlign = TextAlignEnum.LeftCenter;
            _flex.Styles.Fixed.WordWrap = true;
            //Normal Cells and Column Styles
            _flex.Styles.Normal.Font = new Font("Times New Roman", 12, FontStyle.Regular);
            _flex.Styles.Normal.TextAlign = TextAlignEnum.LeftCenter;
            _flex.Styles.Normal.Border.Style = BorderStyleEnum.Fillet;
            _flex.Cols["Theaters Covered"].TextAlign = TextAlignEnum.LeftCenter;
            //"Film "Column Style
            _flex.Cols["Film"].Style.Font = new Font("Times New Roman", 14, FontStyle.Bold);
            _flex.Cols["Film"].Style.WordWrap = true;
            //Custom Format For Columns
            _flex.Cols["Budget"].Format = "'$'#,##.##'M'";
            _flex.Cols["Opening Weekend Collection"].Format = "'$'#,##.##'M'";
            _flex.Cols["WorldWide Collection"].Format = "'$'#,##.##'M'";
            _flex.Cols["Release Date"].Format = "D";
        }

        #endregion

        #region Data Binding Code
        private DataTable GetDataTable()
        {
            string connectionString = String.Format(ConfigurationManager.ConnectionStrings["dbConnectionString"].ConnectionString);
            OleDbConnection conn = new OleDbConnection(connectionString);
            OleDbDataAdapter adapter = new OleDbDataAdapter(ConfigurationManager.ConnectionStrings["dbSelectQuery"].ConnectionString, conn);
            adapter.Fill(_collectionTable);
            return _collectionTable;
        }
        #endregion
    }
}
